(function ($, Drupal, drupalSettings) {
  'use strict';

  Drupal.gglMapPaths = Drupal.gglMapPaths || {};
  Drupal.gglMapPaths.allPaths = Drupal.gglMapPaths.allPaths || {};


  Drupal.gglMapPaths.pathSettings = {
    icons: [
      {
        icon: {},
        offset: '100%',
        repeat: '50px'
      },
    ],
    /*geodesic: true,*/
    strokeColor: "#707070",
    strokeOpacity: 0.7,
    strokeWeight: 2,
  };


  /**
   * Initialize the markers based on the data coming from the collection.
   * @param collection
   * @param collectionData
   */
  Drupal.gglMapPaths.initPaths = function (collection, collectionData) {
    let _self = this;

    if ("items" in collectionData) {
      $.each(collectionData.items, function (index, pathData) {
        if ("id" in pathData) {
          _self.allPaths[pathData.id] = _self.createPath(collection, pathData);
        }
      });
    }
  };



  /**
   * Create polyline.
   * @param index
   * @param data
   */
  Drupal.gglMapPaths.createPath = function (index, data) {
    let _self = this;

    const lineSymbol = {
      path: google.maps.SymbolPath.FORWARD_CLOSED_ARROW,
    };
    let settings = _self.pathSettings;
    settings.icons[0].icon = lineSymbol;

    let path = new google.maps.Polyline(settings);

    let points = [];
    $.each(data.points, function (index, element) {
      points.push({'lat': element.lat[0], 'lng': element.lon[0]});
    });
    path.setPath(points);

    path.setMap(Drupal.gglMap.map);
    return path;
  };

  /**
   * Add collection to path.
   * @param collectionId
   * @param path
   */
  Drupal.gglMapPaths.addCollectionToPath = function (collectionId, path) {
    if (!('collection' in path.data)) {
      path.data.collection = [];
    }
    if (!path.data.collection.includes(collectionId)) {
      path.data.collection.push(collectionId);
    }
  };

})(jQuery, Drupal);
